# Goonj  (WORK In Progress -- Comming Soon!!)
A python library to enable easy alerting services across multiple channels.

## Requirement

### What?
A library that can communicate with any alerting channel like Email, SMS, Slack etc..
A library that can generate reports by aggregating information and sending an alert when it crosses customizable thresholds.

### Why?
We often raise alerts from code. Sometimes these alerts require some processing themselves which litter the actual code.
Getting an aggregated alert allows us to determine if there are any major breakages in the product and act on them quickly. It also allows us to determine the severity of the alert in case we’re getting a lot of them through the day.

## Getting started

TBF

## Installation

Simply use the following command to install the latest released version:

    pip install goonj

## Configuration

TBF

## Key Usage points

Here are some of the key points to be kept in

## Limitations

Here are the basic limitations which need to be kept in mind while using the library:
1. TBF

## Roadmap

The current limitation of the library is planed to be addressed in the future releases.
also below are some of the key features which are planed for future releases:
1. TBF

## Project history

This project has been inspired to solve basic alerting service requirements.


[1]: TBF
